=====================
Listings / Properties
=====================

There following different types of listing embeddings are available:

- The :doc:`Listing Collection <collection>`
- The :doc:`Recent Listings <recent>`
- The :doc:`Featured Listings <featured>`
- The :doc:`Listing Search <search>`
- The :doc:`Listing Search Banner <search-banner>`

In the next sections we will show you how you can enable and configure those embeddings.

We will also take a look at the :doc:`representation of a single listing <details>`.


.. toctree::
   :hidden:
   :maxdepth: 2

   collection
   recent
   featured
   search
   search-banner
   details
